


library(ggplot2)
library(dplyr)
library(sf)
library(sp)
library(cowplot)







############## DATA ######################################################################
rm(list = ls())
dat00 <- data.frame(read.csv("Results/FuncPhylo_mammals200421.csv", header=T))
dat0 <- subset(dat00, SR.0 > 4)






############## SOME SIMPLE CORRELATIONS ########################################################
dat1 <- cbind.data.frame(SR.0=dat0$SR.0, FD.0=dat0$FD.0, PD.0=dat0$PD.0)
dat1 <- dat1[complete.cases(dat1),]
cor(dat1)
cor.test(dat1$SR.0, dat1$FD.0)
cor.test(dat1$SR.0, dat1$PD.0)
cor.test(dat1$FD.0, dat1$PD.0)





############## HOW THE DIFFERENT THREATS CHANGE FD AND PD ########################################
#----------- CREATES THE BOX PLOTS USED IN FIG 1 OF THE MANUSCRIPT ---------------------------------


#------- Change in FD
dat1 <- cbind.data.frame(FD.change.habitat = dat0$FD.habitat-1, FD.change.hunting = dat0$FD.hunting-1,
	FD.change.climate = dat0$FD.climate-1, FD.change.pollution = dat0$FD.pollution-1, FD.change.prey = dat0$FD.prey-1, FD.change.conflict = dat0$FD.conflict-1, 
	FD.change.nonnatives = dat0$FD.nonnat-1, FD.change.hybrid = dat0$FD.hybrid-1, FD.change.disease = dat0$FD.disease-1, FD.change.inbreeding = dat0$FD.inbreeding-1)
datstack <- stack(dat1)
names(datstack) <- c("diversityloss", "threat")

# one-way ANOVA
resaov <- aov(diversityloss ~ threat, data = datstack) 
summary(resaov)
TukeyHSD(resaov)

# box plot
plotfd <- ggplot(datstack, aes(x=threat, y=diversityloss)) + geom_boxplot(outlier.shape=NA, fill='#A4A4A4', color="black") + 
	ylim(-0.25, 0) + 
	theme_classic() +
	geom_hline(yintercept=0, linetype="dashed", color="black") + 
	geom_point(aes())

# how many data points per category?
dattmp <- na.omit(datstack) 
summary(dattmp)


#------- Change in PD
dat1 <- cbind.data.frame(PD.change.habitat = dat0$PD.habitat-1, PD.change.hunting = dat0$PD.hunting-1,
	PD.change.climate = dat0$PD.climate-1, PD.change.pollution = dat0$PD.pollution-1, PD.change.prey = dat0$PD.prey-1, PD.change.conflict = dat0$PD.conflict-1, 
	PD.change.nonnatives = dat0$PD.nonnat-1, PD.change.hybrid = dat0$PD.hybrid-1, PD.change.disease = dat0$PD.disease-1, PD.change.inbreeding = dat0$PD.inbreeding-1)
datstack <- stack(dat1)
names(datstack) <- c("diversityloss", "threat")

# one-way ANOVA
resaov <- aov(diversityloss ~ threat, data=datstack) 
summary(resaov)
TukeyHSD(resaov)

# box plot
plotpd <- ggplot(datstack, aes(x=threat, y=diversityloss)) + geom_boxplot(outlier.shape=NA, fill='#A4A4A4', color="black") + 
	ylim(-0.25, 0) + 
	theme_classic() +
	geom_hline(yintercept=0, linetype="dashed", color="black") + 
	geom_point(aes())


# how many data points per category?
dattmp <- na.omit(datstack) 
summary(dattmp)


#------ Multi-panel figure
plot_grid(plotfd, plotpd, labels = "AUTO", ncol = 1, nrow = 2, label_size = 11)
ggsave("Results/Graphs/ThreatImpacts_A_fd_B_pd.jpg")


#------ Some associated stats
# "...on average, the impacts of habitat loss and harvest... exceed those of climate change by..."

# factor by which habitat loss impacts on FD exceed those of climate change
(1 - mean(dat0$FD.habitat, na.rm=T)) / (1 - mean(dat0$FD.climate, na.rm=T))

# factor by which hunting impacts on FD exceed those of climate change
(1 - mean(dat0$FD.hunting, na.rm=T)) / (1 - mean(dat0$FD.climate, na.rm=T))

# factor by which habitat impacts on PD exceed those of climate change
(1 - mean(dat0$PD.habitat, na.rm=T)) / (1 - mean(dat0$PD.climate, na.rm=T))

# factor by which hunting impacts on PD exceed those of climate change
(1 - mean(dat0$PD.hunting, na.rm=T)) / (1 - mean(dat0$PD.climate, na.rm=T))









############## CHANGES IN WHICH TRAITS ARE DRIVING DECLINES IN FD? ########################################
# "...Across countries, reductions in mammal functional diversity driven by habitat loss and harvest were 
# correlated with nationwide declines in frugivores..."

#--- habitat
DivChange <- (1 - dat0$FD.habitat)
traitcols <- seq(149, 160, by=1) # columns of dat0 for trait changes
dat1 <- dat0[traitcols]
dat1 <- cbind.data.frame(DivChange, dat1)
dat1 <- dat1[complete.cases(dat1),]
corrs <- cor(dat1)
corrs[,1]

#--- harvest
DivChange <- (1 - dat0$FD.hunting)
traitcols <- seq(161, 172, by=1) # columns of dat0 for trait changes
dat1 <- dat0[traitcols]
dat1 <- cbind.data.frame(DivChange, dat1)
dat1 <- dat1[complete.cases(dat1),]
corrs <- cor(dat1)
corrs[,1]





















